Coverage for tests/historicalletters/test_model.py: 100%

1 import math

2 from unittest.mock import Mock, patch

3 from collections import Counter

4 import pandas as pd

5 import geopandas as gpd

6 from shapely import Point, LineString, contains

7 from pathlib import Path

8 import pytest

9

10

11 from scicom.historicalletters.model import (

12 HistoricalLetters,

13 prune,

14)

15

16

17#####

18# Test model setup

19#####

20

21 def test_model_initialization():

22 """Model initialization puts agents on sheduler."""

23 # initialize model for 30 agents with defaults

24 model = HistoricalLetters(30)

25 # 30 agents should be on the scheduler

26 assert len(model.schedule.agents) == 30